searchData={"items":[{"type":"module","title":"LMStudio","doc":"Elixir client for LM Studio's chat completions API with streaming support.","ref":"LMStudio.html"},{"type":"function","title":"LMStudio.chat/2","doc":"Convenience function for single user message.","ref":"LMStudio.html#chat/2"},{"type":"function","title":"LMStudio.complete/2","doc":"Sends a chat completion request with optional streaming.","ref":"LMStudio.html#complete/2"},{"type":"function","title":"Parameters - LMStudio.complete/2","doc":"- messages: List of message maps with :role and :content keys\n  - opts: Keyword list of options\n    - :model - Model to use (default: from config)\n    - :temperature - Temperature for sampling (default: from config)\n    - :max_tokens - Maximum tokens to generate (default: from config)\n    - :stream - Whether to stream the response (default: false)\n    - :system_prompt - Convenience option to prepend a system message\n    - :stream_callback - Function to handle streaming chunks (required if stream: true)","ref":"LMStudio.html#complete/2-parameters"},{"type":"function","title":"Examples - LMStudio.complete/2","doc":"# Non-streaming request\n    {:ok, response} = LMStudio.complete([\n      %{role: \"user\", content: \"Hello, how are you?\"}\n    ])\n\n    # Streaming request\n    LMStudio.complete(\n      [%{role: \"user\", content: \"Tell me a story\"}],\n      stream: true,\n      stream_callback: fn chunk -> IO.write(chunk) end\n    )\n\n    # With system prompt\n    LMStudio.complete(\n      [%{role: \"user\", content: \"What is Elixir?\"}],\n      system_prompt: \"You are a helpful programming assistant.\"\n    )","ref":"LMStudio.html#complete/2-examples"},{"type":"function","title":"LMStudio.list_models/0","doc":"Lists available models from LM Studio.","ref":"LMStudio.html#list_models/0"},{"type":"function","title":"LMStudio.stream_to_process/3","doc":"Streams a completion response to a process.","ref":"LMStudio.html#stream_to_process/3"},{"type":"function","title":"Parameters - LMStudio.stream_to_process/3","doc":"- messages: List of message maps with :role and :content keys\n  - pid: The process to send tokens to\n  - opts: Keyword list of options (same as complete/2 but without stream_callback)","ref":"LMStudio.html#stream_to_process/3-parameters"},{"type":"function","title":"Message Format - LMStudio.stream_to_process/3","doc":"The target process will receive messages in the format:\n  - `{:lmstudio_token, token}` for each token\n  - `{:lmstudio_done, :ok}` when streaming is complete\n  - `{:lmstudio_error, reason}` if an error occurs","ref":"LMStudio.html#stream_to_process/3-message-format"},{"type":"function","title":"Example - LMStudio.stream_to_process/3","doc":"pid = spawn(fn ->\n      receive_tokens()\n    end)\n    \n    LMStudio.stream_to_process(\n      [%{role: \"user\", content: \"Hello!\"}],\n      pid\n    )\n    \n    defp receive_tokens do\n      receive do\n        {:lmstudio_token, token} ->\n          IO.puts(token)\n          receive_tokens()\n        {:lmstudio_done, :ok} ->\n          IO.puts(\"\\nDone!\")\n        {:lmstudio_error, reason} ->\n          IO.puts(\"Error: #{inspect(reason)}\")\n      end\n    end","ref":"LMStudio.html#stream_to_process/3-example"},{"type":"module","title":"LMStudio.AdvancedMAS","doc":"Advanced Multi-Agent System with collaborative learning,\ngenetic evolution, and emergent behaviors.","ref":"LMStudio.AdvancedMAS.html"},{"type":"type","title":"LMStudio.AdvancedMAS.agent_id/0","doc":"","ref":"LMStudio.AdvancedMAS.html#t:agent_id/0"},{"type":"type","title":"LMStudio.AdvancedMAS.agent_role/0","doc":"","ref":"LMStudio.AdvancedMAS.html#t:agent_role/0"},{"type":"type","title":"LMStudio.AdvancedMAS.agent_spec/0","doc":"","ref":"LMStudio.AdvancedMAS.html#t:agent_spec/0"},{"type":"function","title":"LMStudio.AdvancedMAS.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.AdvancedMAS.html#child_spec/1"},{"type":"function","title":"LMStudio.AdvancedMAS.create_swarm/2","doc":"","ref":"LMStudio.AdvancedMAS.html#create_swarm/2"},{"type":"function","title":"LMStudio.AdvancedMAS.detect_emergent_patterns/0","doc":"","ref":"LMStudio.AdvancedMAS.html#detect_emergent_patterns/0"},{"type":"function","title":"LMStudio.AdvancedMAS.evolve_generation/0","doc":"","ref":"LMStudio.AdvancedMAS.html#evolve_generation/0"},{"type":"type","title":"LMStudio.AdvancedMAS.genome/0","doc":"","ref":"LMStudio.AdvancedMAS.html#t:genome/0"},{"type":"function","title":"LMStudio.AdvancedMAS.get_system_state/0","doc":"","ref":"LMStudio.AdvancedMAS.html#get_system_state/0"},{"type":"type","title":"LMStudio.AdvancedMAS.knowledge_atom/0","doc":"","ref":"LMStudio.AdvancedMAS.html#t:knowledge_atom/0"},{"type":"function","title":"LMStudio.AdvancedMAS.share_knowledge/3","doc":"","ref":"LMStudio.AdvancedMAS.html#share_knowledge/3"},{"type":"function","title":"LMStudio.AdvancedMAS.start_link/1","doc":"","ref":"LMStudio.AdvancedMAS.html#start_link/1"},{"type":"type","title":"LMStudio.AdvancedMAS.state/0","doc":"","ref":"LMStudio.AdvancedMAS.html#t:state/0"},{"type":"function","title":"LMStudio.AdvancedMAS.visualize_network/0","doc":"","ref":"LMStudio.AdvancedMAS.html#visualize_network/0"},{"type":"module","title":"LMStudio.CodeGeneration","doc":"Dynamic code generation system that leverages deep Erlang/OTP knowledge.\n\nThis module can generate, modify, and evolve Erlang/Elixir code based on:\n- OTP behaviors (GenServer, Supervisor, Application, GenStateMachine, etc.)\n- Functional programming patterns\n- Concurrent programming patterns\n- Fault tolerance patterns\n- Performance optimization patterns","ref":"LMStudio.CodeGeneration.html"},{"type":"function","title":"LMStudio.CodeGeneration.evolve_code/2","doc":"","ref":"LMStudio.CodeGeneration.html#evolve_code/2"},{"type":"function","title":"LMStudio.CodeGeneration.generate_agent_pattern/2","doc":"","ref":"LMStudio.CodeGeneration.html#generate_agent_pattern/2"},{"type":"function","title":"LMStudio.CodeGeneration.generate_application/3","doc":"","ref":"LMStudio.CodeGeneration.html#generate_application/3"},{"type":"function","title":"LMStudio.CodeGeneration.generate_distributed_worker/2","doc":"","ref":"LMStudio.CodeGeneration.html#generate_distributed_worker/2"},{"type":"function","title":"LMStudio.CodeGeneration.generate_genserver/3","doc":"","ref":"LMStudio.CodeGeneration.html#generate_genserver/3"},{"type":"function","title":"LMStudio.CodeGeneration.generate_pool_manager/3","doc":"","ref":"LMStudio.CodeGeneration.html#generate_pool_manager/3"},{"type":"function","title":"LMStudio.CodeGeneration.generate_registry_worker/2","doc":"","ref":"LMStudio.CodeGeneration.html#generate_registry_worker/2"},{"type":"function","title":"LMStudio.CodeGeneration.generate_state_machine/3","doc":"","ref":"LMStudio.CodeGeneration.html#generate_state_machine/3"},{"type":"function","title":"LMStudio.CodeGeneration.generate_supervisor/3","doc":"","ref":"LMStudio.CodeGeneration.html#generate_supervisor/3"},{"type":"function","title":"LMStudio.CodeGeneration.generate_task_supervisor_worker/2","doc":"","ref":"LMStudio.CodeGeneration.html#generate_task_supervisor_worker/2"},{"type":"function","title":"LMStudio.CodeGeneration.optimize_for_fault_tolerance/1","doc":"","ref":"LMStudio.CodeGeneration.html#optimize_for_fault_tolerance/1"},{"type":"function","title":"LMStudio.CodeGeneration.optimize_for_performance/1","doc":"","ref":"LMStudio.CodeGeneration.html#optimize_for_performance/1"},{"type":"function","title":"LMStudio.CodeGeneration.save_generated_code/2","doc":"","ref":"LMStudio.CodeGeneration.html#save_generated_code/2"},{"type":"module","title":"LMStudio.CognitiveAgent","doc":"Self-modifying cognitive agent that can think and evolve its own reasoning patterns.\n\nThis agent uses the LMStudio client to generate responses while continuously\nmodifying its own prompts and behavioral patterns through MetaDSL mutations.","ref":"LMStudio.CognitiveAgent.html"},{"type":"function","title":"LMStudio.CognitiveAgent.add_performance_score/2","doc":"","ref":"LMStudio.CognitiveAgent.html#add_performance_score/2"},{"type":"function","title":"LMStudio.CognitiveAgent.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.CognitiveAgent.html#child_spec/1"},{"type":"function","title":"LMStudio.CognitiveAgent.evolve_autonomously/2","doc":"","ref":"LMStudio.CognitiveAgent.html#evolve_autonomously/2"},{"type":"function","title":"LMStudio.CognitiveAgent.get_grid_data/1","doc":"","ref":"LMStudio.CognitiveAgent.html#get_grid_data/1"},{"type":"function","title":"LMStudio.CognitiveAgent.get_state/1","doc":"","ref":"LMStudio.CognitiveAgent.html#get_state/1"},{"type":"function","title":"LMStudio.CognitiveAgent.process_query/3","doc":"","ref":"LMStudio.CognitiveAgent.html#process_query/3"},{"type":"function","title":"LMStudio.CognitiveAgent.start_link/1","doc":"","ref":"LMStudio.CognitiveAgent.html#start_link/1"},{"type":"type","title":"LMStudio.CognitiveAgent.state/0","doc":"","ref":"LMStudio.CognitiveAgent.html#t:state/0"},{"type":"module","title":"LMStudio.Config","doc":"Configuration module for LMStudio client.\n\nYou can configure the client in your config.exs:\n\n    config :lmstudio,\n      base_url: \"http://localhost:1234\",\n      default_model: \"your-model-name\",\n      default_temperature: 0.7,\n      default_max_tokens: 2048","ref":"LMStudio.Config.html"},{"type":"function","title":"LMStudio.Config.base_url/0","doc":"","ref":"LMStudio.Config.html#base_url/0"},{"type":"function","title":"LMStudio.Config.default_max_tokens/0","doc":"","ref":"LMStudio.Config.html#default_max_tokens/0"},{"type":"function","title":"LMStudio.Config.default_model/0","doc":"","ref":"LMStudio.Config.html#default_model/0"},{"type":"function","title":"LMStudio.Config.default_temperature/0","doc":"","ref":"LMStudio.Config.html#default_temperature/0"},{"type":"module","title":"LMStudio.ErlangKnowledgeBase","doc":"Comprehensive Erlang/OTP Knowledge Base for Dynamic Code Generation.\n\nThis module contains deep knowledge about Erlang patterns, OTP behaviors,\nconcurrency models, fault tolerance, and best practices from decades of\nErlang evolution and real-world usage.","ref":"LMStudio.ErlangKnowledgeBase.html"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.generate_code_from_pattern/2","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#generate_code_from_pattern/2"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_all_patterns/0","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_all_patterns/0"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_best_practices_for_behavior/1","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_best_practices_for_behavior/1"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_common_antipatterns/0","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_common_antipatterns/0"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_concurrency_patterns/0","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_concurrency_patterns/0"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_distribution_patterns/0","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_distribution_patterns/0"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_evolution_suggestions/2","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_evolution_suggestions/2"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_fault_tolerance_patterns/0","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_fault_tolerance_patterns/0"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_otp_behaviors/0","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_otp_behaviors/0"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_pattern_recommendations/1","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_pattern_recommendations/1"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_pattern_template/1","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_pattern_template/1"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.get_performance_patterns/0","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#get_performance_patterns/0"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.load_knowledge_pattern/1","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#load_knowledge_pattern/1"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.save_knowledge_pattern/2","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#save_knowledge_pattern/2"},{"type":"function","title":"LMStudio.ErlangKnowledgeBase.search_patterns/1","doc":"","ref":"LMStudio.ErlangKnowledgeBase.html#search_patterns/1"},{"type":"module","title":"LMStudio.EvolutionCoordinator","doc":"Coordinates evolution cycles and cross-pollination between agents.","ref":"LMStudio.EvolutionCoordinator.html"},{"type":"function","title":"LMStudio.EvolutionCoordinator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.EvolutionCoordinator.html#child_spec/1"},{"type":"function","title":"LMStudio.EvolutionCoordinator.generate_code_from_insights/1","doc":"","ref":"LMStudio.EvolutionCoordinator.html#generate_code_from_insights/1"},{"type":"function","title":"LMStudio.EvolutionCoordinator.get_agent_names/0","doc":"","ref":"LMStudio.EvolutionCoordinator.html#get_agent_names/0"},{"type":"function","title":"LMStudio.EvolutionCoordinator.get_learning_trajectory/0","doc":"","ref":"LMStudio.EvolutionCoordinator.html#get_learning_trajectory/0"},{"type":"function","title":"LMStudio.EvolutionCoordinator.get_system_state/0","doc":"","ref":"LMStudio.EvolutionCoordinator.html#get_system_state/0"},{"type":"function","title":"LMStudio.EvolutionCoordinator.run_evolution_cycle/1","doc":"","ref":"LMStudio.EvolutionCoordinator.html#run_evolution_cycle/1"},{"type":"function","title":"LMStudio.EvolutionCoordinator.start_continuous_evolution/1","doc":"","ref":"LMStudio.EvolutionCoordinator.html#start_continuous_evolution/1"},{"type":"function","title":"LMStudio.EvolutionCoordinator.start_link/1","doc":"","ref":"LMStudio.EvolutionCoordinator.html#start_link/1"},{"type":"function","title":"LMStudio.EvolutionCoordinator.stop_continuous_evolution/0","doc":"","ref":"LMStudio.EvolutionCoordinator.html#stop_continuous_evolution/0"},{"type":"module","title":"LMStudio.EvolutionSystem","doc":"Supervisor and coordinator for the continuous evolution system.\n\nManages multiple cognitive agents and facilitates cross-pollination\nof successful patterns between agents.","ref":"LMStudio.EvolutionSystem.html"},{"type":"function","title":"LMStudio.EvolutionSystem.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.EvolutionSystem.html#child_spec/1"},{"type":"function","title":"LMStudio.EvolutionSystem.generate_code_from_insights/1","doc":"","ref":"LMStudio.EvolutionSystem.html#generate_code_from_insights/1"},{"type":"function","title":"LMStudio.EvolutionSystem.get_agent_names/0","doc":"","ref":"LMStudio.EvolutionSystem.html#get_agent_names/0"},{"type":"function","title":"LMStudio.EvolutionSystem.get_learning_trajectory/0","doc":"","ref":"LMStudio.EvolutionSystem.html#get_learning_trajectory/0"},{"type":"function","title":"LMStudio.EvolutionSystem.get_system_state/0","doc":"","ref":"LMStudio.EvolutionSystem.html#get_system_state/0"},{"type":"function","title":"LMStudio.EvolutionSystem.run_evolution_cycle/1","doc":"","ref":"LMStudio.EvolutionSystem.html#run_evolution_cycle/1"},{"type":"function","title":"LMStudio.EvolutionSystem.start_continuous_evolution/1","doc":"","ref":"LMStudio.EvolutionSystem.html#start_continuous_evolution/1"},{"type":"function","title":"LMStudio.EvolutionSystem.start_link/1","doc":"","ref":"LMStudio.EvolutionSystem.html#start_link/1"},{"type":"function","title":"LMStudio.EvolutionSystem.stop_continuous_evolution/0","doc":"","ref":"LMStudio.EvolutionSystem.html#stop_continuous_evolution/0"},{"type":"module","title":"LMStudio.Examples","doc":"Examples of using the LMStudio client module.","ref":"LMStudio.Examples.html"},{"type":"function","title":"LMStudio.Examples.conversation_example/0","doc":"","ref":"LMStudio.Examples.html#conversation_example/0"},{"type":"function","title":"LMStudio.Examples.list_models_example/0","doc":"","ref":"LMStudio.Examples.html#list_models_example/0"},{"type":"function","title":"LMStudio.Examples.simple_chat_example/0","doc":"","ref":"LMStudio.Examples.html#simple_chat_example/0"},{"type":"function","title":"LMStudio.Examples.streaming_example/0","doc":"","ref":"LMStudio.Examples.html#streaming_example/0"},{"type":"module","title":"LMStudio.JsonMock","doc":"Simple JSON mock for testing without external dependencies","ref":"LMStudio.JsonMock.html"},{"type":"function","title":"LMStudio.JsonMock.decode/1","doc":"","ref":"LMStudio.JsonMock.html#decode/1"},{"type":"function","title":"LMStudio.JsonMock.decode!/1","doc":"","ref":"LMStudio.JsonMock.html#decode!/1"},{"type":"function","title":"LMStudio.JsonMock.encode!/1","doc":"","ref":"LMStudio.JsonMock.html#encode!/1"},{"type":"module","title":"LMStudio.LegitimateMAS","doc":"A legitimate Multi-Agent System implementation following FIPA standards and MAS principles.\n\nFeatures:\n- BDI (Belief-Desire-Intention) agent architecture\n- FIPA ACL (Agent Communication Language) compliant messaging\n- Contract Net Protocol for task allocation\n- Blackboard system for shared knowledge\n- Agent negotiation and coordination\n- Organizational structures and roles","ref":"LMStudio.LegitimateMAS.html"},{"type":"function","title":"LMStudio.LegitimateMAS.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.LegitimateMAS.html#child_spec/1"},{"type":"function","title":"LMStudio.LegitimateMAS.create_agent/2","doc":"","ref":"LMStudio.LegitimateMAS.html#create_agent/2"},{"type":"function","title":"LMStudio.LegitimateMAS.get_system_state/0","doc":"","ref":"LMStudio.LegitimateMAS.html#get_system_state/0"},{"type":"function","title":"LMStudio.LegitimateMAS.init/1","doc":"Callback implementation for  GenServer.init/1 .","ref":"LMStudio.LegitimateMAS.html#init/1"},{"type":"function","title":"LMStudio.LegitimateMAS.start_link/1","doc":"","ref":"LMStudio.LegitimateMAS.html#start_link/1"},{"type":"function","title":"LMStudio.LegitimateMAS.submit_task/2","doc":"","ref":"LMStudio.LegitimateMAS.html#submit_task/2"},{"type":"module","title":"LMStudio.LegitimateMAS.ACL","doc":"","ref":"LMStudio.LegitimateMAS.ACL.html"},{"type":"function","title":"LMStudio.LegitimateMAS.ACL.new/2","doc":"","ref":"LMStudio.LegitimateMAS.ACL.html#new/2"},{"type":"module","title":"LMStudio.LegitimateMAS.BDIAgent","doc":"","ref":"LMStudio.LegitimateMAS.BDIAgent.html"},{"type":"function","title":"LMStudio.LegitimateMAS.BDIAgent.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.LegitimateMAS.BDIAgent.html#child_spec/1"},{"type":"function","title":"LMStudio.LegitimateMAS.BDIAgent.init/1","doc":"Callback implementation for  GenServer.init/1 .","ref":"LMStudio.LegitimateMAS.BDIAgent.html#init/1"},{"type":"function","title":"LMStudio.LegitimateMAS.BDIAgent.start_link/1","doc":"","ref":"LMStudio.LegitimateMAS.BDIAgent.html#start_link/1"},{"type":"module","title":"LMStudio.LegitimateMAS.Blackboard","doc":"","ref":"LMStudio.LegitimateMAS.Blackboard.html"},{"type":"function","title":"LMStudio.LegitimateMAS.Blackboard.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.LegitimateMAS.Blackboard.html#child_spec/1"},{"type":"function","title":"LMStudio.LegitimateMAS.Blackboard.init/1","doc":"Callback implementation for  GenServer.init/1 .","ref":"LMStudio.LegitimateMAS.Blackboard.html#init/1"},{"type":"function","title":"LMStudio.LegitimateMAS.Blackboard.post/3","doc":"","ref":"LMStudio.LegitimateMAS.Blackboard.html#post/3"},{"type":"function","title":"LMStudio.LegitimateMAS.Blackboard.read/2","doc":"","ref":"LMStudio.LegitimateMAS.Blackboard.html#read/2"},{"type":"function","title":"LMStudio.LegitimateMAS.Blackboard.start_link/1","doc":"","ref":"LMStudio.LegitimateMAS.Blackboard.html#start_link/1"},{"type":"function","title":"LMStudio.LegitimateMAS.Blackboard.subscribe/3","doc":"","ref":"LMStudio.LegitimateMAS.Blackboard.html#subscribe/3"},{"type":"module","title":"LMStudio.LegitimateMAS.ContractNet","doc":"Implements the Contract Net Protocol for distributed task allocation","ref":"LMStudio.LegitimateMAS.ContractNet.html"},{"type":"function","title":"LMStudio.LegitimateMAS.ContractNet.evaluate_proposals/1","doc":"","ref":"LMStudio.LegitimateMAS.ContractNet.html#evaluate_proposals/1"},{"type":"function","title":"LMStudio.LegitimateMAS.ContractNet.initiate_contract/2","doc":"","ref":"LMStudio.LegitimateMAS.ContractNet.html#initiate_contract/2"},{"type":"function","title":"LMStudio.LegitimateMAS.ContractNet.submit_proposal/3","doc":"","ref":"LMStudio.LegitimateMAS.ContractNet.html#submit_proposal/3"},{"type":"module","title":"LMStudio.LegitimateMAS.Organization","doc":"Defines organizational structures and roles for agents","ref":"LMStudio.LegitimateMAS.Organization.html"},{"type":"function","title":"LMStudio.LegitimateMAS.Organization.create_hierarchy/0","doc":"","ref":"LMStudio.LegitimateMAS.Organization.html#create_hierarchy/0"},{"type":"function","title":"LMStudio.LegitimateMAS.Organization.create_holarchy/0","doc":"","ref":"LMStudio.LegitimateMAS.Organization.html#create_holarchy/0"},{"type":"module","title":"LMStudio.MetaDSL","doc":"Self-Modifying MetaDSL Cognitive System for Elixir\n================================================\n\nA continuously evolving system that uses MetaDSL to mutate its own prompts,\nreasoning patterns, and cognitive strategies through recursive self-improvement.\n\nThis system combines:\n- MetaDSL for prompt mutation\n- Cognitive agents with thinking capabilities  \n- Self-modification through grid mutations\n- Continuous learning and evolution using OTP","ref":"LMStudio.MetaDSL.html"},{"type":"module","title":"LMStudio.MetaDSL.Mutation","doc":"Represents a mutation operation","ref":"LMStudio.MetaDSL.Mutation.html"},{"type":"function","title":"LMStudio.MetaDSL.Mutation.new/3","doc":"","ref":"LMStudio.MetaDSL.Mutation.html#new/3"},{"type":"type","title":"LMStudio.MetaDSL.Mutation.t/0","doc":"","ref":"LMStudio.MetaDSL.Mutation.html#t:t/0"},{"type":"module","title":"LMStudio.MetaDSL.MutationType","doc":"Types of mutations for self-modification","ref":"LMStudio.MetaDSL.MutationType.html"},{"type":"function","title":"LMStudio.MetaDSL.MutationType.from_string/1","doc":"","ref":"LMStudio.MetaDSL.MutationType.html#from_string/1"},{"type":"type","title":"LMStudio.MetaDSL.MutationType.t/0","doc":"","ref":"LMStudio.MetaDSL.MutationType.html#t:t/0"},{"type":"function","title":"LMStudio.MetaDSL.MutationType.types/0","doc":"","ref":"LMStudio.MetaDSL.MutationType.html#types/0"},{"type":"module","title":"LMStudio.MetaDSL.SelfModifyingGrid","doc":"GenServer that maintains a grid of data that can modify itself based on performance feedback.\n\nThe grid stores key-value pairs and tracks mutations, performance metrics, and evolution.\nEnhanced with persistence capabilities for continuous learning.","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.add_performance/2","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#add_performance/2"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.analyze_patterns/1","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#analyze_patterns/1"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#child_spec/1"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.export_grid/2","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#export_grid/2"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.get_data/1","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#get_data/1"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.get_state/1","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#get_state/1"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.import_grid/2","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#import_grid/2"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.load_from_persistence/2","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#load_from_persistence/2"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.mutate/2","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#mutate/2"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.persist_now/1","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#persist_now/1"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.render_grid/1","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#render_grid/1"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.start_link/1","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#start_link/1"},{"type":"type","title":"LMStudio.MetaDSL.SelfModifyingGrid.state/0","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#t:state/0"},{"type":"function","title":"LMStudio.MetaDSL.SelfModifyingGrid.suggest_mutations/1","doc":"","ref":"LMStudio.MetaDSL.SelfModifyingGrid.html#suggest_mutations/1"},{"type":"module","title":"LMStudio.MultiAgentSystem","doc":"Advanced Multi-Agent System with function calling, tool use, and collaborative problem solving.","ref":"LMStudio.MultiAgentSystem.html"},{"type":"function","title":"LMStudio.MultiAgentSystem.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.MultiAgentSystem.html#child_spec/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.get_agents/0","doc":"","ref":"LMStudio.MultiAgentSystem.html#get_agents/0"},{"type":"function","title":"LMStudio.MultiAgentSystem.init/1","doc":"Callback implementation for  GenServer.init/1 .","ref":"LMStudio.MultiAgentSystem.html#init/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.send_message/4","doc":"","ref":"LMStudio.MultiAgentSystem.html#send_message/4"},{"type":"function","title":"LMStudio.MultiAgentSystem.start_link/1","doc":"","ref":"LMStudio.MultiAgentSystem.html#start_link/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.submit_task/2","doc":"","ref":"LMStudio.MultiAgentSystem.html#submit_task/2"},{"type":"module","title":"LMStudio.MultiAgentSystem.Agent","doc":"","ref":"LMStudio.MultiAgentSystem.Agent.html"},{"type":"function","title":"LMStudio.MultiAgentSystem.Agent.new/2","doc":"","ref":"LMStudio.MultiAgentSystem.Agent.html#new/2"},{"type":"module","title":"LMStudio.MultiAgentSystem.Message","doc":"","ref":"LMStudio.MultiAgentSystem.Message.html"},{"type":"function","title":"LMStudio.MultiAgentSystem.Message.new/4","doc":"","ref":"LMStudio.MultiAgentSystem.Message.html#new/4"},{"type":"module","title":"LMStudio.MultiAgentSystem.Tools","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html"},{"type":"function","title":"LMStudio.MultiAgentSystem.Tools.get_all_tools/0","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html#get_all_tools/0"},{"type":"function","title":"LMStudio.MultiAgentSystem.Tools.get_tool/1","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html#get_tool/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.Tools.handle_analyze_code/1","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html#handle_analyze_code/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.Tools.handle_execute_code/1","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html#handle_execute_code/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.Tools.handle_generate_code/1","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html#handle_generate_code/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.Tools.handle_query_knowledge/1","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html#handle_query_knowledge/1"},{"type":"function","title":"LMStudio.MultiAgentSystem.Tools.handle_search_web/1","doc":"","ref":"LMStudio.MultiAgentSystem.Tools.html#handle_search_web/1"},{"type":"module","title":"LMStudio.MutationParser","doc":"Parser for extracting MetaDSL mutation commands from LLM responses.","ref":"LMStudio.MutationParser.html"},{"type":"function","title":"LMStudio.MutationParser.parse/1","doc":"","ref":"LMStudio.MutationParser.html#parse/1"},{"type":"module","title":"LMStudio.NeuralArchitecture","doc":"Advanced Neural Architecture for Cognitive Agents\n\nImplements self-modifying neural networks, attention mechanisms,\ntransformer architectures, and neural evolution strategies.","ref":"LMStudio.NeuralArchitecture.html"},{"type":"function","title":"LMStudio.NeuralArchitecture.analyze_attention_patterns/2","doc":"","ref":"LMStudio.NeuralArchitecture.html#analyze_attention_patterns/2"},{"type":"function","title":"LMStudio.NeuralArchitecture.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.NeuralArchitecture.html#child_spec/1"},{"type":"function","title":"LMStudio.NeuralArchitecture.create_model/3","doc":"","ref":"LMStudio.NeuralArchitecture.html#create_model/3"},{"type":"function","title":"LMStudio.NeuralArchitecture.evolve_model/3","doc":"","ref":"LMStudio.NeuralArchitecture.html#evolve_model/3"},{"type":"function","title":"LMStudio.NeuralArchitecture.forward_pass/4","doc":"","ref":"LMStudio.NeuralArchitecture.html#forward_pass/4"},{"type":"function","title":"LMStudio.NeuralArchitecture.get_model_state/2","doc":"","ref":"LMStudio.NeuralArchitecture.html#get_model_state/2"},{"type":"function","title":"LMStudio.NeuralArchitecture.start_link/1","doc":"","ref":"LMStudio.NeuralArchitecture.html#start_link/1"},{"type":"function","title":"LMStudio.NeuralArchitecture.train_step/3","doc":"","ref":"LMStudio.NeuralArchitecture.html#train_step/3"},{"type":"module","title":"LMStudio.NeuralArchitecture.AttentionMechanism","doc":"Multi-head attention mechanism","ref":"LMStudio.NeuralArchitecture.AttentionMechanism.html"},{"type":"function","title":"LMStudio.NeuralArchitecture.AttentionMechanism.forward/5","doc":"","ref":"LMStudio.NeuralArchitecture.AttentionMechanism.html#forward/5"},{"type":"function","title":"LMStudio.NeuralArchitecture.AttentionMechanism.new/3","doc":"","ref":"LMStudio.NeuralArchitecture.AttentionMechanism.html#new/3"},{"type":"module","title":"LMStudio.NeuralArchitecture.CognitiveTransformer","doc":"Full transformer model for cognitive reasoning","ref":"LMStudio.NeuralArchitecture.CognitiveTransformer.html"},{"type":"function","title":"LMStudio.NeuralArchitecture.CognitiveTransformer.evolve_architecture/2","doc":"","ref":"LMStudio.NeuralArchitecture.CognitiveTransformer.html#evolve_architecture/2"},{"type":"function","title":"LMStudio.NeuralArchitecture.CognitiveTransformer.forward/3","doc":"","ref":"LMStudio.NeuralArchitecture.CognitiveTransformer.html#forward/3"},{"type":"function","title":"LMStudio.NeuralArchitecture.CognitiveTransformer.new/4","doc":"","ref":"LMStudio.NeuralArchitecture.CognitiveTransformer.html#new/4"},{"type":"module","title":"LMStudio.NeuralArchitecture.Neuron","doc":"Individual neuron with adaptive properties","ref":"LMStudio.NeuralArchitecture.Neuron.html"},{"type":"function","title":"LMStudio.NeuralArchitecture.Neuron.adapt_learning_rate/1","doc":"","ref":"LMStudio.NeuralArchitecture.Neuron.html#adapt_learning_rate/1"},{"type":"function","title":"LMStudio.NeuralArchitecture.Neuron.backward/3","doc":"","ref":"LMStudio.NeuralArchitecture.Neuron.html#backward/3"},{"type":"function","title":"LMStudio.NeuralArchitecture.Neuron.forward/3","doc":"","ref":"LMStudio.NeuralArchitecture.Neuron.html#forward/3"},{"type":"function","title":"LMStudio.NeuralArchitecture.Neuron.new/3","doc":"","ref":"LMStudio.NeuralArchitecture.Neuron.html#new/3"},{"type":"type","title":"LMStudio.NeuralArchitecture.Neuron.t/0","doc":"","ref":"LMStudio.NeuralArchitecture.Neuron.html#t:t/0"},{"type":"module","title":"LMStudio.NeuralArchitecture.TransformerLayer","doc":"Transformer layer with self-attention and feed-forward network","ref":"LMStudio.NeuralArchitecture.TransformerLayer.html"},{"type":"function","title":"LMStudio.NeuralArchitecture.TransformerLayer.forward/3","doc":"","ref":"LMStudio.NeuralArchitecture.TransformerLayer.html#forward/3"},{"type":"function","title":"LMStudio.NeuralArchitecture.TransformerLayer.new/4","doc":"","ref":"LMStudio.NeuralArchitecture.TransformerLayer.html#new/4"},{"type":"module","title":"LMStudio.Persistence","doc":"Persistent storage for evolution system with ETS and file-based persistence.\n\nProvides both in-memory (ETS) and disk persistence for:\n- Agent states and grids\n- Evolution cycles and metrics\n- Generated code and patterns\n- Learning history and insights","ref":"LMStudio.Persistence.html"},{"type":"function","title":"LMStudio.Persistence.checkpoint_now/0","doc":"","ref":"LMStudio.Persistence.html#checkpoint_now/0"},{"type":"function","title":"LMStudio.Persistence.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.Persistence.html#child_spec/1"},{"type":"function","title":"LMStudio.Persistence.delete/1","doc":"","ref":"LMStudio.Persistence.html#delete/1"},{"type":"function","title":"LMStudio.Persistence.export_to_file/1","doc":"","ref":"LMStudio.Persistence.html#export_to_file/1"},{"type":"function","title":"LMStudio.Persistence.get/2","doc":"","ref":"LMStudio.Persistence.html#get/2"},{"type":"function","title":"LMStudio.Persistence.get_stats/0","doc":"","ref":"LMStudio.Persistence.html#get_stats/0"},{"type":"function","title":"LMStudio.Persistence.import_from_file/1","doc":"","ref":"LMStudio.Persistence.html#import_from_file/1"},{"type":"function","title":"LMStudio.Persistence.list_keys/1","doc":"","ref":"LMStudio.Persistence.html#list_keys/1"},{"type":"function","title":"LMStudio.Persistence.start_link/1","doc":"","ref":"LMStudio.Persistence.html#start_link/1"},{"type":"function","title":"LMStudio.Persistence.store/3","doc":"","ref":"LMStudio.Persistence.html#store/3"},{"type":"module","title":"LMStudio.Persistence.Helpers","doc":"Helper functions for common persistence operations in the evolution system.","ref":"LMStudio.Persistence.Helpers.html"},{"type":"function","title":"LMStudio.Persistence.Helpers.backup_all_agent_data/1","doc":"","ref":"LMStudio.Persistence.Helpers.html#backup_all_agent_data/1"},{"type":"function","title":"LMStudio.Persistence.Helpers.list_generated_code/0","doc":"","ref":"LMStudio.Persistence.Helpers.html#list_generated_code/0"},{"type":"function","title":"LMStudio.Persistence.Helpers.list_knowledge_patterns/0","doc":"","ref":"LMStudio.Persistence.Helpers.html#list_knowledge_patterns/0"},{"type":"function","title":"LMStudio.Persistence.Helpers.load_agent_grid/1","doc":"","ref":"LMStudio.Persistence.Helpers.html#load_agent_grid/1"},{"type":"function","title":"LMStudio.Persistence.Helpers.load_agent_state/1","doc":"","ref":"LMStudio.Persistence.Helpers.html#load_agent_state/1"},{"type":"function","title":"LMStudio.Persistence.Helpers.load_evolution_cycles/0","doc":"","ref":"LMStudio.Persistence.Helpers.html#load_evolution_cycles/0"},{"type":"function","title":"LMStudio.Persistence.Helpers.load_generated_code/1","doc":"","ref":"LMStudio.Persistence.Helpers.html#load_generated_code/1"},{"type":"function","title":"LMStudio.Persistence.Helpers.load_global_insights/0","doc":"","ref":"LMStudio.Persistence.Helpers.html#load_global_insights/0"},{"type":"function","title":"LMStudio.Persistence.Helpers.load_knowledge_pattern/1","doc":"","ref":"LMStudio.Persistence.Helpers.html#load_knowledge_pattern/1"},{"type":"function","title":"LMStudio.Persistence.Helpers.load_performance_metrics/1","doc":"","ref":"LMStudio.Persistence.Helpers.html#load_performance_metrics/1"},{"type":"function","title":"LMStudio.Persistence.Helpers.restore_agent_data/2","doc":"","ref":"LMStudio.Persistence.Helpers.html#restore_agent_data/2"},{"type":"function","title":"LMStudio.Persistence.Helpers.save_agent_grid/2","doc":"","ref":"LMStudio.Persistence.Helpers.html#save_agent_grid/2"},{"type":"function","title":"LMStudio.Persistence.Helpers.save_agent_state/2","doc":"","ref":"LMStudio.Persistence.Helpers.html#save_agent_state/2"},{"type":"function","title":"LMStudio.Persistence.Helpers.save_evolution_cycle/2","doc":"","ref":"LMStudio.Persistence.Helpers.html#save_evolution_cycle/2"},{"type":"function","title":"LMStudio.Persistence.Helpers.save_generated_code/2","doc":"","ref":"LMStudio.Persistence.Helpers.html#save_generated_code/2"},{"type":"function","title":"LMStudio.Persistence.Helpers.save_global_insights/1","doc":"","ref":"LMStudio.Persistence.Helpers.html#save_global_insights/1"},{"type":"function","title":"LMStudio.Persistence.Helpers.save_knowledge_pattern/2","doc":"","ref":"LMStudio.Persistence.Helpers.html#save_knowledge_pattern/2"},{"type":"function","title":"LMStudio.Persistence.Helpers.save_performance_metrics/2","doc":"","ref":"LMStudio.Persistence.Helpers.html#save_performance_metrics/2"},{"type":"module","title":"LMStudio.QuantumReasoning","doc":"Quantum-Inspired Reasoning Engine for Cognitive Agents\n\nImplements quantum superposition of thought states, entanglement between concepts,\nand quantum interference patterns for advanced reasoning capabilities.","ref":"LMStudio.QuantumReasoning.html"},{"type":"function","title":"LMStudio.QuantumReasoning.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"LMStudio.QuantumReasoning.html#child_spec/1"},{"type":"function","title":"LMStudio.QuantumReasoning.create_superposition/3","doc":"","ref":"LMStudio.QuantumReasoning.html#create_superposition/3"},{"type":"function","title":"LMStudio.QuantumReasoning.entangle_concepts/4","doc":"","ref":"LMStudio.QuantumReasoning.html#entangle_concepts/4"},{"type":"function","title":"LMStudio.QuantumReasoning.evolve_quantum_field/2","doc":"","ref":"LMStudio.QuantumReasoning.html#evolve_quantum_field/2"},{"type":"function","title":"LMStudio.QuantumReasoning.get_field_state/1","doc":"","ref":"LMStudio.QuantumReasoning.html#get_field_state/1"},{"type":"function","title":"LMStudio.QuantumReasoning.inject_dark_knowledge/3","doc":"","ref":"LMStudio.QuantumReasoning.html#inject_dark_knowledge/3"},{"type":"function","title":"LMStudio.QuantumReasoning.measure_reasoning_state/2","doc":"","ref":"LMStudio.QuantumReasoning.html#measure_reasoning_state/2"},{"type":"function","title":"LMStudio.QuantumReasoning.start_link/1","doc":"","ref":"LMStudio.QuantumReasoning.html#start_link/1"},{"type":"module","title":"LMStudio.QuantumReasoning.QuantumField","doc":"Represents a field of quantum reasoning states","ref":"LMStudio.QuantumReasoning.QuantumField.html"},{"type":"function","title":"LMStudio.QuantumReasoning.QuantumField.new/2","doc":"","ref":"LMStudio.QuantumReasoning.QuantumField.html#new/2"},{"type":"module","title":"LMStudio.QuantumReasoning.QuantumState","doc":"Represents a quantum superposition of reasoning states","ref":"LMStudio.QuantumReasoning.QuantumState.html"},{"type":"function","title":"LMStudio.QuantumReasoning.QuantumState.add_entanglement/4","doc":"","ref":"LMStudio.QuantumReasoning.QuantumState.html#add_entanglement/4"},{"type":"function","title":"LMStudio.QuantumReasoning.QuantumState.collapse_to_measurement/2","doc":"","ref":"LMStudio.QuantumReasoning.QuantumState.html#collapse_to_measurement/2"},{"type":"function","title":"LMStudio.QuantumReasoning.QuantumState.new/2","doc":"","ref":"LMStudio.QuantumReasoning.QuantumState.html#new/2"},{"type":"type","title":"LMStudio.QuantumReasoning.QuantumState.t/0","doc":"","ref":"LMStudio.QuantumReasoning.QuantumState.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}